@@ -7,7 +7,9 @@ from dagster import (
     Output,
     OutputDefinition,
     RetryRequested,
+    VersionStrategy,
     default_executors,
+    fs_io_manager,
     lambda_solid,
     pipeline,
     solid,
@@ -15,7 +17,12 @@ from dagster import (
 from dagster.core.test_utils import nesting_composite_pipeline
 from dagster_celery import celery_executor
 
-celery_mode_defs = [ModeDefinition(executor_defs=default_executors + [celery_executor])]
+celery_mode_defs = [
+    ModeDefinition(
+        executor_defs=default_executors + [celery_executor],
+        resource_defs={"io_manager": fs_io_manager},
+    )
+]
 
 
 # test_execute pipelines
@@ -317,3 +324,26 @@ def fooqueue(context):
 @pipeline(mode_defs=celery_mode_defs)
 def multiqueue_pipeline():
     fooqueue()
+
+
+@solid
+def bar_solid():
+    return "bar"
+
+
+class BasicVersionStrategy(VersionStrategy):
+    def get_solid_version(self, _):
+        return "bar"
+
+
+@pipeline(
+    mode_defs=[
+        ModeDefinition(
+            resource_defs={"io_manager": fs_io_manager},
+            executor_defs=default_executors + [celery_executor],
+        )
+    ],
+    version_strategy=BasicVersionStrategy(),
+)
+def bar_pipeline():
+    bar_solid()
